package com.tzld.piaoquan.risk.control.service.impl;

import com.alibaba.fastjson.JSON;
import com.tzld.piaoquan.risk.control.config.QywxConfig;
import com.tzld.piaoquan.risk.control.model.po.UserBase;
import com.tzld.piaoquan.risk.control.model.qywx.QwCommonResModel;
import com.tzld.piaoquan.risk.control.model.qywx.RiskUserInfo;
import com.tzld.piaoquan.risk.control.model.qywx.RoomListResponse;
import com.tzld.piaoquan.risk.control.model.qywx.RoomMemberListInfo;
import com.tzld.piaoquan.risk.control.util.HttpClientUtil;
import com.tzld.piaoquan.risk.control.util.HttpPoolClient;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.lang.reflect.Array;
import java.util.*;

@Slf4j
@Service
public class RiskUserOperateService {
    @Autowired
    private QywxConfig qywxConfig; // 注入配置类
    @Autowired
    private QywxUserDataService qwUserService;
    private static final HttpPoolClient httpPoolClientDefault = HttpClientUtil.create(10000, 10000, 2000, 5000, 5, 10000);
    private static final Logger LOGGER = LoggerFactory.getLogger(RiskUserHandleService.class);

    public boolean checkAndKickExternalUser(UserBase staff,RiskUserInfo riskUserInfo,long vid,long roomId) {
        boolean inRoom = isInRoom(staff, roomId, vid);

        return true;
    }

    private void kick(UserBase staff, long roomId, long vid) {
        Map<String, Object> requestBody = new HashMap<>();
        requestBody.put("uuid", staff.getUuid());
        requestBody.put("oprType", 1);
        requestBody.put("blacklist_vid",Arrays.asList(vid));
        String params = JSON.toJSONString(requestBody);
        Optional<String> response = httpPoolClientDefault.postJson(qywxConfig.getDomain() + qywxConfig.getPath("get-chatList"), params);
    }

    //增加校验，是否在群内
    public boolean isInRoom(UserBase staff, long roomId,long vid) {
        List<RoomMemberListInfo.Member> memberList = getRoomMemberList(staff, roomId);
        for (RoomMemberListInfo.Member member : memberList) {
            if (member.getUin() == vid) {
                return true;
            }
        }
        return false;
    }

    private List<RoomMemberListInfo.Member> getRoomMemberList(UserBase staff, long roomId) {
        Map<String, Object> requestBody = new HashMap<>();
        requestBody.put("uuid", staff.getUuid());
        requestBody.put("roomId", roomId);
        LOGGER.info("getRoomMemberList, staff: {}", staff);
        String params = JSON.toJSONString(requestBody);
        Optional<String> response = httpPoolClientDefault.postJson(qywxConfig.getDomain() + qywxConfig.getPath("get-roomMembers"), params);
        List<RoomMemberListInfo.Member> memberList = new ArrayList<>();
        if (response.isPresent()) {
            QwCommonResModel<RoomMemberListInfo> memberInfo = QwCommonResModel.parseResponse(response.get(), RoomMemberListInfo.class);
            if (memberInfo.getErrcode() == 0) {
                memberList = memberInfo.getData().getMemberList();
            }
        }
        return memberList;
    }
}
